@@ -6,14 +6,12 @@
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef KSMTP_FAKESERVER_H
-#define KSMTP_FAKESERVER_H
+#pragma once
 
 #include <QMutex>
-#include <QTcpServer>
-#include <QTcpSocket>
 #include <QThread>
-
+class QTcpServer;
+class QTcpSocket;
 Q_DECLARE_METATYPE(QList<QByteArray>)
 
 class FakeServer : public QThread
@@ -52,4 +50,3 @@ private:
     QList<QTcpSocket *> m_clientSockets;
 };
 
-#endif // KSMTP_FAKESERVER_H
