@@ -6,8 +6,7 @@
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef KSMTP_JOB_H
-#define KSMTP_JOB_H
+#pragma once
 
 #include "ksmtp_export.h"
 
@@ -45,8 +44,7 @@ protected:
     explicit Job(Session *session);
     explicit Job(JobPrivate &dd);
 
-    JobPrivate *const d_ptr;
+    std::unique_ptr<JobPrivate> const d_ptr;
 };
 }
 
-#endif
