@@ -42,7 +42,6 @@ public:
         : JobPrivate(session, name)
         , m_preferedAuthMode(LoginJob::Login)
         , m_actualAuthMode(LoginJob::UnknownAuth)
-        , m_encryptionMode(LoginJob::Unencrypted)
         , q(job)
     {
     }
@@ -65,7 +64,6 @@ public:
     QString m_password;
     LoginJob::AuthMode m_preferedAuthMode;
     LoginJob::AuthMode m_actualAuthMode;
-    LoginJob::EncryptionMode m_encryptionMode;
 
     sasl_conn_t *m_saslConn = nullptr;
     sasl_interact_t *m_saslClient = nullptr;
@@ -114,42 +112,15 @@ LoginJob::AuthMode LoginJob::usedAuthMode() const
     return d_func()->m_actualAuthMode;
 }
 
-void LoginJob::setEncryptionMode(EncryptionMode mode)
-{
-    Q_D(LoginJob);
-    d->m_encryptionMode = mode;
-}
-
-LoginJob::EncryptionMode LoginJob::encryptionMode() const
-{
-    return d_func()->m_encryptionMode;
-}
-
 void LoginJob::doStart()
 {
     Q_D(LoginJob);
-
-    const auto negotiatedEnc = d->sessionInternal()->negotiatedEncryption();
-    if (negotiatedEnc != QSsl::UnknownProtocol) {
-        // Socket already encrypted, pretend we did not want any
-        d->m_encryptionMode = Unencrypted;
+    if (d->sessionInternal()->negotiatedEncryption() == QSsl::UnknownProtocol && d->m_session->encryptionMode() != Session::Unencrypted) {
+        qFatal("LoginJob started despite session not being encrypted!");
     }
 
-    if (d->m_encryptionMode == SSLorTLS) {
-        d->sessionInternal()->startSsl(QSsl::SecureProtocols);
-    } else if (d->m_encryptionMode == STARTTLS) {
-        if (session()->allowsTls()) {
-            sendCommand(QByteArrayLiteral("STARTTLS"));
-        } else {
-            qCWarning(KSMTP_LOG) << "STARTTLS not supported by the server!";
-            setError(KJob::UserDefinedError);
-            setErrorText(i18n("STARTTLS is not supported by the server, try using SSL/TLS instead."));
-            emitResult();
-        }
-    } else {
-        if (!d->authenticate()) {
-            emitResult();
-        }
+    if (!d->authenticate()) {
+        emitResult();
     }
 }
 
@@ -160,19 +131,6 @@ void LoginJob::handleResponse(const ServerResponse &r)
     // Handle server errors
     handleErrors(r);
 
-    // Server accepts TLS connection
-    if (r.isCode(220)) {
-        d->sessionInternal()->startSsl(QSsl::SecureProtocols);
-        return;
-    }
-
-    // Available authentication mechanisms
-    if (r.isCode(25) && r.text().startsWith("AUTH ")) { // krazy:exclude=strings
-        d->sessionInternal()->setAuthenticationMethods(r.text().remove(0, QByteArray("AUTH ").count()).split(' '));
-        d->authenticate();
-        return;
-    }
-
     // Send account data
     if (r.isCode(334)) {
         if (d->m_actualAuthMode == Plain) {
@@ -276,7 +234,7 @@ bool LoginJobPrivate::sasl_challenge(const QByteArray &challenge)
         }
     }
 
-    Q_FOREVER {
+    for (;;) {
         result = sasl_client_step(m_saslConn, challenge.isEmpty() ? nullptr : challenge.constData(), challenge.size(), &m_saslClient, &out, &outLen);
         if (result == SASL_INTERACT) {
             if (!sasl_interact()) {
@@ -328,7 +286,7 @@ bool LoginJobPrivate::authenticate()
     const char *actualMech = nullptr;
     const auto authMode = authCommand(m_actualAuthMode);
 
-    Q_FOREVER {
+    for (;;) {
         qCDebug(KSMTP_LOG) << "Trying authmod" << authMode;
         result = sasl_client_start(m_saslConn, authMode.constData(), &m_saslClient, &out, &outLen, &actualMech);
         if (result == SASL_INTERACT) {
