@@ -6,8 +6,7 @@
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-#ifndef KSMTP_SENDJOB_H
-#define KSMTP_SENDJOB_H
+#pragma once
 
 #include "ksmtp_export.h"
 
@@ -58,10 +57,14 @@ public:
      */
     Q_REQUIRED_RESULT int size() const;
 
+    /**
+     * Set Delivery Status Notification.
+     */
+    void setDeliveryStatusNotification(bool b);
+
 protected:
     void doStart() override;
     void handleResponse(const ServerResponse &r) override;
 };
 }
 
-#endif // KSMTP_SENDJOB_H
