@@ -15,7 +15,6 @@
 #include "session_p.h"
 #include "sessionthread_p.h"
 
-#include <QEventLoop>
 #include <QHostAddress>
 #include <QHostInfo>
 #include <QPointer>
@@ -30,9 +29,6 @@ Q_DECLARE_METATYPE(KSslErrorUiData)
 SessionPrivate::SessionPrivate(Session *session)
     : QObject(session)
     , q(session)
-    , m_state(Session::Disconnected)
-    , m_socketTimerInterval(60000)
-    , m_sslVersion(QSsl::UnknownProtocol)
 {
     qRegisterMetaType<QSsl::SslProtocol>();
     qRegisterMetaType<KSslErrorUiData>();
@@ -140,6 +136,16 @@ Session::State Session::state() const
     return d->m_state;
 }
 
+Session::EncryptionMode Session::encryptionMode() const
+{
+    return d->m_encryptionMode;
+}
+
+void Session::setEncryptionMode(Session::EncryptionMode mode)
+{
+    d->m_encryptionMode = mode;
+}
+
 bool Session::allowsTls() const
 {
     return d->m_allowsTls;
@@ -187,19 +193,12 @@ QString Session::customHostname() const
 
 void Session::open()
 {
+    d->m_sslVersion = QSsl::UnknownProtocol;
+    d->m_thread->setConnectWithTls(d->m_encryptionMode == Session::TLS);
     QTimer::singleShot(0, d->m_thread, &SessionThread::reconnect);
     d->startSocketTimer();
 }
 
-void Session::openAndWait()
-{
-    QEventLoop loop(nullptr);
-    d->m_startLoop = &loop;
-    open();
-    d->m_startLoop->exec();
-    d->m_startLoop = nullptr;
-}
-
 void Session::quit()
 {
     if (d->m_state == Session::Disconnected) {
@@ -210,23 +209,6 @@ void Session::quit()
     d->sendData("QUIT");
 }
 
-void Session::quitAndWait()
-{
-    if (d->m_state == Session::Disconnected) {
-        return;
-    }
-
-    QEventLoop loop;
-    connect(this, &Session::stateChanged, this, [&](Session::State state) {
-        if (state == Session::Disconnected) {
-            loop.quit();
-        }
-    });
-    d->setState(Quitting);
-    d->sendData("QUIT");
-    loop.exec();
-}
-
 void SessionPrivate::setState(Session::State s)
 {
     if (m_state == s) {
@@ -235,11 +217,6 @@ void SessionPrivate::setState(Session::State s)
 
     m_state = s;
     Q_EMIT q->stateChanged(m_state);
-
-    // After a handshake success or failure, exit the startup event loop if any
-    if (m_startLoop && (m_state == Session::NotAuthenticated || m_state == Session::Disconnected)) {
-        m_startLoop->quit();
-    }
 }
 
 void SessionPrivate::sendData(const QByteArray &data)
@@ -254,7 +231,7 @@ void SessionPrivate::sendData(const QByteArray &data)
 
 void SessionPrivate::responseReceived(const ServerResponse &r)
 {
-    // qCDebug(KSMTP_LOG) << "S:: [" << r.code() << "]" << (r.isMultiline() ? "-" : " ") << r.text();
+    qCDebug(KSMTP_LOG) << "S:: [" << r.code() << "]" << (r.isMultiline() ? "-" : " ") << r.text();
 
     if (m_state == Session::Quitting) {
         m_thread->closeSocket();
@@ -281,9 +258,22 @@ void SessionPrivate::responseReceived(const ServerResponse &r)
             }
 
             if (!r.isMultiline()) {
-                setState(Session::NotAuthenticated);
-                startNext();
+                if (m_encryptionMode == Session::STARTTLS && m_sslVersion == QSsl::UnknownProtocol) {
+                    if (m_allowsTls) {
+                        m_starttlsSent = true;
+                        sendData(QByteArrayLiteral("STARTTLS"));
+                    } else {
+                        qCWarning(KSMTP_LOG) << "STARTTLS not supported by the server!";
+                        q->quit();
+                    }
+                } else {
+                    setState(Session::NotAuthenticated);
+                    startNext();
+                }
             }
+        } else if (r.isCode(220) && m_starttlsSent) { // STARTTLS accepted
+            m_starttlsSent = false;
+            startSsl();
         }
     }
 
@@ -302,18 +292,8 @@ void SessionPrivate::responseReceived(const ServerResponse &r)
 void SessionPrivate::socketConnected()
 {
     stopSocketTimer();
+    m_sslVersion = QSsl::UnknownProtocol;
     setState(Session::Ready);
-
-    bool useSsl = false;
-    if (!m_queue.isEmpty()) {
-        if (auto login = qobject_cast<LoginJob *>(m_queue.first())) {
-            useSsl = login->encryptionMode() == LoginJob::SSLorTLS;
-        }
-    }
-
-    if (q->state() == Session::Ready && useSsl) {
-        startNext();
-    }
 }
 
 void SessionPrivate::socketDisconnected()
@@ -334,14 +314,9 @@ void SessionPrivate::socketDisconnected()
     m_queue.clear();
 }
 
-void SessionPrivate::startSsl(QSsl::SslProtocol version)
+void SessionPrivate::startSsl()
 {
-    QMetaObject::invokeMethod(
-        m_thread,
-        [this, version] {
-            m_thread->startSsl(version);
-        },
-        Qt::QueuedConnection);
+    QMetaObject::invokeMethod(m_thread, &SessionThread::startSsl, Qt::QueuedConnection);
 }
 
 QSsl::SslProtocol SessionPrivate::negotiatedEncryption() const
@@ -452,12 +427,6 @@ void SessionPrivate::stopSocketTimer()
     disconnect(&m_socketTimer, &QTimer::timeout, this, &SessionPrivate::onSocketTimeout);
 }
 
-void SessionPrivate::restartSocketTimer()
-{
-    stopSocketTimer();
-    startSocketTimer();
-}
-
 void SessionPrivate::onSocketTimeout()
 {
     socketDisconnected();
