@@ -17,7 +17,6 @@
 #include <QSslSocket>
 
 class KJob;
-class QEventLoop;
 
 namespace KSmtp
 {
@@ -38,7 +37,7 @@ public:
     void addJob(Job *job);
     void sendData(const QByteArray &data);
     void setState(Session::State s);
-    void startSsl(QSsl::SslProtocol version);
+    void startSsl();
 
     QSsl::SslProtocol negotiatedEncryption() const;
 
@@ -63,18 +62,17 @@ private:
     void startNext();
     void startSocketTimer();
     void stopSocketTimer();
-    void restartSocketTimer();
 
     Session *const q;
 
     // Smtp session
-    Session::State m_state;
+    Session::State m_state = Session::Disconnected;
+    Session::EncryptionMode m_encryptionMode = Session::Unencrypted;
     SessionThread *m_thread = nullptr;
     SessionUiProxy::Ptr m_uiProxy;
-    int m_socketTimerInterval = 0;
+    int m_socketTimerInterval = 60000;
     QTimer m_socketTimer;
-    QEventLoop *m_startLoop = nullptr;
-    QSsl::SslProtocol m_sslVersion;
+    QSsl::SslProtocol m_sslVersion = QSsl::UnknownProtocol;
 
     // Jobs
     bool m_jobRunning = false;
@@ -85,6 +83,7 @@ private:
     bool m_ehloRejected = false;
     int m_size = 0;
     bool m_allowsTls = false;
+    bool m_starttlsSent = false;
     QStringList m_authModes;
     QString m_customHostname;
 };
