@@ -27,7 +27,6 @@ SessionThread::SessionThread(const QString &hostName, quint16 port, Session *ses
     , m_parentSession(session)
     , m_hostName(hostName)
     , m_port(port)
-    , m_useProxy(false)
 {
     moveToThread(this);
 
@@ -125,7 +124,11 @@ void SessionThread::reconnect()
             qCDebug(KSMTP_LOG) << "Using the default system proxy to connect to the SMTP server.";
         }
 
-        m_socket->connectToHost(hostName(), port());
+        if (m_useTls) {
+            m_socket->connectToHostEncrypted(hostName(), port());
+        } else {
+            m_socket->connectToHost(hostName(), port());
+        }
     }
 }
 
@@ -134,16 +137,14 @@ void SessionThread::run()
     m_socket = std::make_unique<QSslSocket>();
 
     connect(m_socket.get(), &QSslSocket::readyRead, this, &SessionThread::readResponse, Qt::QueuedConnection);
+    connect(m_socket.get(), &QSslSocket::encrypted, this, &SessionThread::sslConnected);
 
     connect(m_socket.get(), &QSslSocket::disconnected, m_parentSession->d, &SessionPrivate::socketDisconnected);
     connect(m_socket.get(), &QSslSocket::connected, m_parentSession->d, &SessionPrivate::socketConnected);
-    connect(m_socket.get(),
-            QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::errorOccurred),
-            this,
-            [this](QAbstractSocket::SocketError err) {
-                qCWarning(KSMTP_LOG) << "SMTP Socket error:" << err << m_socket->errorString();
-                Q_EMIT m_parentSession->connectionError(m_socket->errorString());
-            });
+    connect(m_socket.get(), &QAbstractSocket::errorOccurred, this, [this](QAbstractSocket::SocketError err) {
+        qCWarning(KSMTP_LOG) << "SMTP Socket error:" << err << m_socket->errorString();
+        Q_EMIT m_parentSession->connectionError(m_socket->errorString());
+    });
     connect(this, &SessionThread::encryptionNegotiationResult, m_parentSession->d, &SessionPrivate::encryptionNegotiationResult);
 
     connect(this, &SessionThread::responseReceived, m_parentSession->d, &SessionPrivate::responseReceived);
@@ -158,6 +159,12 @@ void SessionThread::setUseNetworkProxy(bool useProxy)
     m_useProxy = useProxy;
 }
 
+void SessionThread::setConnectWithTls(bool useTls)
+{
+    QMutexLocker locker(&m_mutex);
+    m_useTls = useTls;
+}
+
 ServerResponse SessionThread::parseResponse(const QByteArray &resp)
 {
     QByteArray response(resp);
@@ -191,13 +198,11 @@ ServerResponse SessionThread::parseResponse(const QByteArray &resp)
     return ServerResponse(returnCode, response, multiline);
 }
 
-void SessionThread::startSsl(QSsl::SslProtocol protocol)
+void SessionThread::startSsl()
 {
     QMutexLocker locker(&m_mutex);
 
-    m_socket->setProtocol(protocol);
     m_socket->ignoreSslErrors(); // don't worry, we DO handle the errors ourselves below
-    connect(m_socket.get(), &QSslSocket::encrypted, this, &SessionThread::sslConnected);
     m_socket->startClientEncryption();
 }
 
