@@ -33,13 +33,14 @@ public:
     Q_REQUIRED_RESULT quint16 port() const;
 
     void setUseNetworkProxy(bool useProxy);
+    void setConnectWithTls(bool useTls);
 
     void handleSslErrorResponse(bool ignoreError);
 
 public Q_SLOTS:
     void reconnect();
     void closeSocket();
-    void startSsl(QSsl::SslProtocol version);
+    void startSsl();
     void sendData(const QByteArray &payload);
 
 Q_SIGNALS:
@@ -69,6 +70,7 @@ private:
     QString m_hostName;
     quint16 m_port;
     bool m_useProxy = false;
+    bool m_useTls = false;
 };
 }
 
